@@ -21,9 +21,10 @@
  * 02111-1307, USA.
  */
 
+#include <config.h>
 #include "edge-resistance.h"
 #include "boxes.h"
-#include "display.h"
+#include "display-private.h"
 #include "workspace.h"
 
 /* A simple macro for whether a given window's edges are potentially
